import * as ec2 from '@aws-cdk/aws-ec2';
import * as eks from '@aws-cdk/aws-eks';
import * as iam from '@aws-cdk/aws-iam';
import { IHostedZone } from '@aws-cdk/aws-route53';
import * as cdk from '@aws-cdk/core';
import { NodeTaint } from '../types/cluster';
import * as ema from './eks-managed-addon';
export { VpcCniAddonVersion } from './eks-managed-addon';
/**
 * Constructor properties for SuperEks.
 *
 * Get merged with `defaultSuperEksProps`.
 *
 * @stability stable
 */
export interface SuperEksProps {
    /**
     * Wrapper for all cluster props>.
     *
     * @stability stable
     */
    readonly clusterProps?: eks.ClusterProps;
    /**
     * Additional Roles that should be granted cluster admin privileges.
     *
     * Can also be added manually after cluster creation by using `cluster.awsAuth.addMastersRole(role)`.
     *
     * @stability stable
     */
    readonly adminRoles?: iam.IRole[];
    /**
     * A hosted zone for DNS management.
     *
     * Records in this zone will be created for your workloads by 'external-dns'.
     *
     * @stability stable
     */
    readonly hostedZone: IHostedZone;
    /**
     * Config for the Nodegroup created to host SuperEks specific workloads.
     *
     * If you override the `launchTemplateSpec` you're responsible for adding the necessary userdata to taint the nodes,
     * see `../config/cluster#nodeTaintUserdata`
     *
     * @stability stable
     */
    readonly superEksNodegroupProps?: eks.NodegroupOptions;
    /**
     * Specific properties for EKS managed add-ons.
     *
     * @stability stable
     */
    readonly addonProps?: AddonProps;
}
/**
 * Specific properties for EKS managed add-ons.
 *
 * @stability stable
 */
export interface AddonProps {
    /**
     * @stability stable
     */
    readonly vpcCniAddonVersion?: ema.VpcCniAddonVersion;
}
/**
 * Default config for SuperEks
 */
export declare const defaultSuperEksProps: {
    clusterProps: {
        version: eks.KubernetesVersion;
    };
    superEksNodegroupProps: {
        nodegroupName: string;
        labels: {
            workload: string;
        };
        instanceTypes: ec2.InstanceType[];
    };
};
/**
 * SuperEks wraps eks.Cluster to include batteries.
 *
 * @stability stable
 */
export declare class SuperEks extends cdk.Construct {
    private props;
    /**
     * The created cluster.
     *
     * @stability stable
     * @attribute true
     */
    readonly cluster: eks.Cluster;
    /**
     * `eks.Nodegroup`s added to the cluster.
     *
     * @default An internal `eks.Nodegroup` will be created for super-eks related workloads
     * @stability stable
     * @attribute true
     */
    readonly additionalNodegroups: eks.Nodegroup[];
    /**
     * @stability stable
     */
    constructor(scope: cdk.Construct, id: string, props: SuperEksProps);
    /**
     * Generates `ec2.MultipartUserData` to attach to a `eks.Nodegroup` `ec2.LaunchTemplate` so that the Nodes are getting tainted with the given `NodeTaint`.
     *
     * @param taint the taint that should be applied to the Nodes.
     * @stability stable
     */
    nodeTaintUserdata(taint: NodeTaint): ec2.MultipartUserData;
    private addAdminRoles;
    private configureCluster;
    private addSuperEksNodegroup;
    private addManagedVpcCniAddon;
    private hardenNodes;
    private configureExternalDNS;
    private configureAwsLoadBalancerController;
    private configureFluentBit;
    /**
     * Adds PDBs to system workloads so that the cluster autoscaler can evict them.
     */
    private addPodDisruptionBudgets;
}
